const path = require('path');
const program = require('commander');
const execa = require('execa');
const moveFile = require('./helper/moveFile');
const myPackage = require('../package.json');
const createLogger = require('progress-estimator');
const cwd = process.cwd();
const pkg = require(path.join(cwd, 'package.json'));
const logger = createLogger();

program
  .version(myPackage.version);

const fileDir = path.join(cwd, '/dist');
const releaseDir = path.join(cwd, '/release');

// build
program
  .command('build <desc>')
  .action(async (desc) => {
    const build = async () => {
      await execa.shell('npm run build');
      return;
    }
    // git release
    const gitRelease = async () => {
      await execa.shell('git add .', { cwd: releaseDir });
      await execa.shell(`git commit -m "${desc}, ${new Date().toLocaleString()}"`, { cwd: releaseDir });
      await execa.shell(`git push origin master:${pkg.branch ? pkg.branch.release : 'release'}`, { cwd: releaseDir });
      return;
    }
    async function run() {
      await logger(build(), "run build", {
        estimate: 10000
      });

      // 移动文件夹
      await logger(moveFile(fileDir, releaseDir), "move files", {
        estimate: 100
      });

      await logger(gitRelease(), "git release", {
        estimate: 2000
      });
    };
    await run();
  });

program.parse(process.argv);
